import json as _json

import requests as _re
from bs4 import BeautifulSoup as _BeautifulSoup


def scrape(login: str, password: str):
    session = _re.session()
    login_site_r = session.get('https://mobilevikings.pl/en/account/login/')
    login_soup = _BeautifulSoup(login_site_r.content, features='html.parser')
    csrf_middle_token = login_soup.find('input', attrs={'name': 'csrfmiddlewaretoken'})['value']
    payload = {
        'csrfmiddlewaretoken': csrf_middle_token,
        'next': '/mysims/',
        'username': login,
        'password': password
    }
    login_r = session.post('https://mobilevikings.pl/en/account/login/', data=payload,
                           headers={'Referer': 'https://mobilevikings.pl/en/account/login/'})
    json_r = session.get('https://mobilevikings.pl/mysims/sim/148128/balance/json/',
                         headers={'Referer': login_r.url})

    return _json.loads(json_r.content)



import pathlib

import setuptools

HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text()

setuptools.setup(
    name="mobile-vikings-scraper",
    version="1.0.2",
    description="Scraper for Mobile Vikings in Poland",
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/TheLastGimbus/mobile-vikings-scraper',
    author='TheLastGimbus',
    author_email='mateusz.soszynski@tuta.io',
    license='Apache',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        'License :: OSI Approved :: Apache Software License',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Telecommunications Industry',
        'Topic :: Internet :: WWW/HTTP'
    ],
    install_requires=(HERE / 'requirements.txt').read_text().split('\n'),
)
